@@ -1,8 +1,8 @@
 from extras.plugins import PluginTemplateExtension
 from .models import Secret
 
-class DeviceSecrets(PluginTemplateExtension):
-    model = 'dcim.device'
+
+class Secrets(PluginTemplateExtension):
 
     def right_page(self):
         obj = self.context['object']
@@ -10,4 +10,13 @@ class DeviceSecrets(PluginTemplateExtension):
             'secrets': Secret.objects.filter(device=obj),
         })
 
-template_extensions = [DeviceSecrets]
\ No newline at end of file
+
+class DeviceSecrets(Secrets):
+    model = 'dcim.Device'
+
+
+class VMSecrets(Secrets):
+    model = 'virtualization.VirtualMachine'
+
+
+template_extensions = [DeviceSecrets, VMSecrets]
